package it.pierovdfn.pdfcompare;

import java.io.OutputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

import javax.servlet.ServletException;

import javax.servlet.annotation.MultipartConfig;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.Part;

import com.itextpdf.text.Document;

import com.itextpdf.text.pdf.PdfReader;
import com.itextpdf.text.pdf.PdfCopy;
import com.itextpdf.text.pdf.PdfSmartCopy;
import com.itextpdf.text.pdf.PdfImportedPage;

@MultipartConfig
public class MergeServlet extends HttpServlet {

	final int BUFFER_SIZE = 4096;

	public void init() throws ServletException {
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		try {
			Part doc1 = null;
			Part doc2 = null;
			ByteArrayOutputStream merged = new ByteArrayOutputStream();

			String pages[] = req.getParameter("pages").trim().split("\\s+");
			doc1 = req.getPart("doc1");
			doc2 = req.getPart("doc2");

			PdfReader doc1Reader = new PdfReader(doc1.getInputStream());
			PdfReader doc2Reader = new PdfReader(doc2.getInputStream());

			Document document = new Document();
			PdfCopy pdfCopy = new PdfSmartCopy(document, merged);
			document.open();

			for (String page : pages) {
				String doc = page.substring(0, 4);
				int pageNum;
				try {
					pageNum = Integer.parseInt(page.substring(5));
				} catch (NumberFormatException e) {
					continue;
				}

				PdfImportedPage importedPage = null;
				if (doc.equals("doc1")) {
					importedPage = pdfCopy.getImportedPage(doc1Reader, pageNum);
				} else if (doc.equals("doc2")) {
					importedPage = pdfCopy.getImportedPage(doc2Reader, pageNum);
				}

				pdfCopy.addPage(importedPage);
			}

			document.close();
			pdfCopy.close();
			doc1Reader.close();
			doc2Reader.close();

			doc1.delete();
			doc2.delete();

			res.setContentType("application/pdf");
			res.addHeader("Content-Disposition", "attachment; filename=merged.pdf");
			res.setContentLength(merged.size());

			OutputStream out = res.getOutputStream();
			out.write(merged.toByteArray());
			out.flush();
			out.close();
		} catch(Exception e) {
			throw new IOException(e);
		}
	}


	public void destroy() {
	}
}
